﻿<#

.SYNOPSIS

File Name     : FindUnusedVDAs.ps1
Author        : George Spiers
Email         : george@jgspiers.com
Twitter       : @JGSpiers 
Website       : www.jgspiers.com
Date Created  : 25.04.2017
Tested on     : Windows Server 2012 R2 - XenDesktop 7.13

.DESCRIPTION

This script finds and reports to text file VDAs which have not been logged on to for a defined period of time. This is helpful when determining VDAs that are now unused and can be re-assigned or decommisioned.  

.NOTES

To avoid failure, run PowerShell as an administrator with atleast Read Only Citrix administrator permissions.

.LINK


.CHANGE LOG

#>
                                                                            
# Captures date into variable. Desktops not logged on to before the specified date are filtered. Use American date format. Example: 03/25/2017
$date = Read-Host -Prompt "Find desktops not logged on to before this specified date"

# Create "Output" directory in C:\
if (!(Test-Path C:\Output)) {mkdir C:\Output}

# Load Citrix PS Snap-ins
asnp Citrix.*

# Find VDAs not used within last month (American date format is used)
Get-BrokerDesktop -MaxRecordCount 2147483647 | Select-Object DNSName,LastConnectionTime,LastConnectedUser | where {$_.LastConnectionTime -lt "$date"} | Sort-Object {$_.LastConnectionTime -as [datetime]} > C:\Output\UnusedVDAs.txt